public inbox for gdb-cvs@sourceware.org
help / color / mirror / Atom feed
* [binutils-gdb] gdb/tui: rename tui_layout_split:set_weights_from_heights
@ 2022-04-03 14:42 Andrew Burgess
  0 siblings, 0 replies; only message in thread
From: Andrew Burgess @ 2022-04-03 14:42 UTC (permalink / raw)
  To: gdb-cvs

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=ef466e0f0827555fcae21a905b3a2b9a6c0a5712

commit ef466e0f0827555fcae21a905b3a2b9a6c0a5712
Author: Andrew Burgess <aburgess@redhat.com>
Date:   Fri Jan 28 12:00:31 2022 +0000

    gdb/tui: rename tui_layout_split:set_weights_from_heights
    
    In a following commit I'm going to add the ability to change the width
    of a tui window (when in a horizontal layout).  As a result, some of
    the places where we currently hard-code references to height need to
    be changed to handle either height, or width, based on whether we are
    in a vertical, or horizontal layout.
    
    This commit renames set_weights_from_heights to
    set_weights_from_sizes, and makes the function use either the height,
    or width as appropriate.
    
    Currently, the only place that we call this function is from the
    tui_layout_split::set_height function, in a part of the code we will
    only reach for vertical layouts, so the new code is not actually being
    used, but, this small change will help make later patches smaller, so
    I'm proposing this as a stand alone change.
    
    There should be no user visible changes after this commit.

Diff:
---
 gdb/tui/tui-layout.c | 9 +++++----
 gdb/tui/tui-layout.h | 5 +++--
 2 files changed, 8 insertions(+), 6 deletions(-)

diff --git a/gdb/tui/tui-layout.c b/gdb/tui/tui-layout.c
index 33e0d2f8cda..62fb54c40bd 100644
--- a/gdb/tui/tui-layout.c
+++ b/gdb/tui/tui-layout.c
@@ -561,10 +561,11 @@ tui_layout_split::bottom_boxed_p () const
 /* See tui-layout.h.  */
 
 void
-tui_layout_split::set_weights_from_heights ()
+tui_layout_split::set_weights_from_sizes ()
 {
   for (int i = 0; i < m_splits.size (); ++i)
-    m_splits[i].weight = m_splits[i].layout->height;
+    m_splits[i].weight
+      = m_vertical ? m_splits[i].layout->height : m_splits[i].layout->width;
 }
 
 /* See tui-layout.h.  */
@@ -596,7 +597,7 @@ tui_layout_split::set_height (const char *name, int new_height)
   if (m_splits[found_index].layout->height == new_height)
     return HANDLED;
 
-  set_weights_from_heights ();
+  set_weights_from_sizes ();
   int delta = m_splits[found_index].weight - new_height;
   m_splits[found_index].weight = new_height;
 
@@ -634,7 +635,7 @@ tui_layout_split::set_height (const char *name, int new_height)
     {
       warning (_("Invalid window height specified"));
       /* Effectively undo any modifications made here.  */
-      set_weights_from_heights ();
+      set_weights_from_sizes ();
     }
   else
     {
diff --git a/gdb/tui/tui-layout.h b/gdb/tui/tui-layout.h
index acea7ac8f64..8f41835b94c 100644
--- a/gdb/tui/tui-layout.h
+++ b/gdb/tui/tui-layout.h
@@ -217,8 +217,9 @@ protected:
 
 private:
 
-  /* Set the weights from the current heights.  */
-  void set_weights_from_heights ();
+  /* Set the weights from the current heights (when m_vertical is true) or
+     widths (when m_vertical is false).  */
+  void set_weights_from_sizes ();
 
   struct split
   {


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-04-03 14:42 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-04-03 14:42 [binutils-gdb] gdb/tui: rename tui_layout_split:set_weights_from_heights Andrew Burgess

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).